@@ -18,7 +18,7 @@ class GNEB_Node(NodeMixin):
     """A class that represents a GNEB calculation on a single chain. Can spawn children if cutting of the chain becomes necessary."""
 
     def __init__(self, name, input_file, output_folder, initial_chain_file=None, gneb_workflow_log_file=None, parent=None, children=None):
-        from spirit import simulation
+        from spirit import simulation, io
 
         """Constructor."""
         self.chain_file : str             = ""
@@ -47,12 +47,16 @@ class GNEB_Node(NodeMixin):
         self.before_llg_callback    = None
         self.intermediate_minima = []
         self.child_indices       = []
-        self._ci                 = False
-        self._converged          = False
         self.image_types         = []
-        self.history = []
+        self.history             = []
         self.solver_llg  = simulation.SOLVER_LBFGS_OSO
         self.solver_gneb = simulation.SOLVER_VP_OSO
+        self.chain_write_fileformat = io.FILEFORMAT_OVF_BIN
+
+        # private fields
+        self._ci                 = False
+        self._converged          = False
+        self._log                = True # flag to disable/enable logging
 
         # Create output folder
         if not os.path.exists(output_folder):
@@ -66,8 +70,7 @@ class GNEB_Node(NodeMixin):
         if(initial_chain_file):
             if not os.path.exists(initial_chain_file):
                 raise Exception("Initial chain file ({}) does not exist!".format(initial_chain_file))
-            self.initial_chain_file = output_folder + "/root_initial_chain.ovf"
-            shutil.copyfile(initial_chain_file, self.initial_chain_file)
+            self.initial_chain_file = initial_chain_file
             shutil.copyfile(initial_chain_file, self.chain_file)
 
         self.input_file = input_file
@@ -235,7 +238,8 @@ class GNEB_Node(NodeMixin):
             delta_Rx_right           = float(self.delta_Rx_right),
             image_types              = [ [int(t[0]), int(t[1]) ] for t in self.image_types],
             solver_llg               = int(self.solver_llg),
-            solver_gneb              = int(self.solver_gneb)
+            solver_gneb              = int(self.solver_gneb),
+            fileformat               = int(self.chain_write_fileformat)
         )
 
         with open(json_file, "w") as f:
@@ -274,6 +278,7 @@ class GNEB_Node(NodeMixin):
         result.path_shortening_constant = data.get("path", result.path_shortening_constant)
         result.solver_llg               = data.get("solver_llg", result.solver_llg)
         result.solver_gneb              = data.get("solver_gneb", result.solver_gneb)
+        result.chain_write_fileformat   = data.get("fileformat", result.chain_write_fileformat)
 
         result.log("Created from json file {}".format(json_file))
 
@@ -285,20 +290,29 @@ class GNEB_Node(NodeMixin):
 
     def log(self, message):
         """Append a message with date/time information to the log file."""
+        if not self._log:  # if log flag is not set, do nothing
+            return
         now = datetime.now()
         current_time = now.strftime("%m/%d/%Y, %H:%M:%S")
         log_string = "{} [{:^35}] : {}".format(current_time, self.name, message)
         with open(self.gneb_workflow_log_file, "a") as f:
             print(log_string, file=f)
 
+    def enable_log(self):
+        self._log = True
+
+    def disable_log(self):
+        self._log = False
+
     def update_energy_path(self, p_state=None):
         """Updates the current energy path. If p_state is given we just use that, otherwise we have to construct it first"""
         if p_state:
             self.current_energy_path = energy_path_from_p_state(p_state)
             self.noi = self.current_energy_path.noi()
         else:
-            from spirit import state, io
+            from spirit import state, io, chain
             with state.State(self.input_file) as p_state:
+                chain.update_data(p_state)
                 self._prepare_state(p_state)
                 self.update_energy_path(p_state)
 
@@ -319,7 +333,15 @@ class GNEB_Node(NodeMixin):
         """Saves the chain and overwrites the chain_file"""
         from spirit import io
         self.log("Writing chain to {}".format(self.chain_file))
-        io.chain_write(p_state, self.chain_file)
+        io.chain_write(p_state, self.chain_file, fileformat=self.chain_write_fileformat)
+
+    def backup_chain(self, path):
+        """Saves the chain to a file"""
+        from spirit import state, io
+        with state.State(self.input_file) as p_state:
+            self._prepare_state(p_state)
+            self.log("Writing chain to {}".format(path))
+            io.chain_write(p_state, path, fileformat=self.chain_write_fileformat)
 
     def add_child(self, i1, i2, p_state=None):
 
@@ -344,9 +366,11 @@ class GNEB_Node(NodeMixin):
             self.children[-1].n_iterations_check     = self.n_iterations_check
             self.children[-1].n_checks_save          = self.n_checks_save
             self.children[-1].allow_split            = self.allow_split
+            self.children[-1].chain_write_fileformat = self.chain_write_fileformat
+
             self.child_indices.append([i1, i2])
             # Write the chain file
-            chain_write_between(p_state, self.children[-1].chain_file, i1, i2)
+            chain_write_between(p_state, self.children[-1].chain_file, i1, i2, fileformat=self.chain_write_fileformat)
 
         if p_state:
             _helper(p_state)
@@ -598,10 +622,10 @@ class GNEB_Node(NodeMixin):
         from spirit import chain, io, state, parameters
 
         self.log("Preparing for moving endpoints")
-        chain_backup_path = os.path.join(self.output_folder, "chain_backup.ovf")
-        self.log("    Making backup copy of chain in {}".format(chain_backup_path))
 
-        shutil.copy(self.chain_file, chain_backup_path)
+        # chain_backup_path = os.path.join(self.output_folder, "chain_backup.ovf")
+        # self.log("    Making backup copy of chain in {}".format(chain_backup_path))
+        # shutil.copy(self.chain_file, chain_backup_path)
 
         self.target_noi       = 3
         self.moving_endpoints = True
@@ -611,9 +635,10 @@ class GNEB_Node(NodeMixin):
             self._prepare_state(p_state)
             self.update_energy_path(p_state)
 
+            noi = chain.get_noi(p_state)
+
             if idx_mid < 0:
                 E = chain.get_energy(p_state)
-                noi = chain.get_noi(p_state)
                 idx_mid = np.argmax(E)
 
             self.log("    idx_mid = {}".format(idx_mid))
